@@ -9,7 +9,7 @@ use Mojo::SQLite::Migrations;
 use Mojo::URL;
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 has dsn => sub {
   my $uri = Mojo::URL->new->scheme('file')->path(shift->_tempfile);
@@ -103,8 +103,8 @@ Mojo::SQLite - A tiny Mojolicious wrapper for SQLite
 
   # Insert a few rows
   my $db = $sql->db;
-  $sql->query('insert into names (name) values (?)', 'Sara');
-  $sql->query('insert into names (name) values (?)', 'Stefan');
+  $db->query('insert into names (name) values (?)', 'Sara');
+  $db->query('insert into names (name) values (?)', 'Stefan');
 
   # Insert more rows in a transaction
   eval {
